@@ -2,14 +2,17 @@
 # -*- coding: utf-8 -*-
 #
 # Copyright (C) 2015 by Christian Tremblay, P.Eng <christian.tremblay@servisys.com>
-#
 # Licensed under LGPLv3, see file LICENSE in this source tree.
+#
 """
-Repeat read function every delay
+DoOnce.py - execute a task once
 """
 
 from .TaskManager import OneShotTask
+from ..core.utils.notes import note_and_log
 
+
+@note_and_log
 class DoOnce(OneShotTask):
     """
     Start a polling task which is in fact a recurring read of the point.
@@ -26,11 +29,11 @@ class DoOnce(OneShotTask):
 
         :returns: Nothing
         """
-        if hasattr(fnc, '__call__'):
+        if hasattr(fnc, "__call__"):
             self.func = fnc
             OneShotTask.__init__(self)
         else:
-            raise ValueError('You must pass a function to this...')
+            raise ValueError("You must pass a function to this...")
 
     def task(self):
-        self.func()
\ No newline at end of file
+        self.func()
